import React, { useRef, useState, useEffect } from 'react';
import SvgIcon from './SvgIcon';

/**
 * 搜索栏组件
 * @param {Object} props
 * @param {string} props.searchKeyword - 搜索关键词
 * @param {boolean} props.isSearching - 是否正在搜索
 * @param {Function} props.onSearchChange - 搜索关键词变化的回调函数
 * @param {Function} props.onSearch - 提交搜索的回调函数
 * @param {Function} props.onClearSearch - 清除搜索的回调函数
 * @param {string} props.placeholder - 搜索框占位文本
 * @param {string} props.className - 额外的 CSS 类名
 * @param {Array} props.searchResults - 搜索结果
 * @param {boolean} props.isSearchLoading - 搜索是否正在加载
 * @param {Function} props.onResultClick - 点击搜索结果的回调
 * @param {Function} props.onRequestAccess - 申请权限的回调
 */
const SearchBar = ({
    searchKeyword,
    isSearching,
    onSearchChange,
    onSearch,
    onClearSearch,
    placeholder = '搜索...',
    className = 'w-50',
    searchResults = [],
    isSearchLoading = false,
    onResultClick,
    onRequestAccess,
}) => {
    const [showDropdown, setShowDropdown] = useState(false);
    const searchRef = useRef(null);
    const inputRef = useRef(null);

    // 处理点击外部关闭下拉框
    useEffect(() => {
        const handleClickOutside = (event) => {
            if (searchRef.current && !searchRef.current.contains(event.target)) {
                setShowDropdown(false);
            }
        };

        document.addEventListener('mousedown', handleClickOutside);
        return () => {
            document.removeEventListener('mousedown', handleClickOutside);
        };
    }, []);

    // 只有在用户执行搜索后且有结果时显示下拉框
    useEffect(() => {
        if (isSearching && searchResults.length > 0) {
            setShowDropdown(true);
        }
    }, [isSearching, searchResults]);

    // 处理输入变化
    const handleInputChange = (e) => {
        onSearchChange(e);
    };

    // 处理搜索提交
    const handleSubmit = (e) => {
        e.preventDefault();
        onSearch(e);
        // 搜索提交后，如果有关键词，将显示下拉框(由searchResults决定)
    };

    return (
        <div className={`position-relative ${className}`} ref={searchRef}>
            <form className='d-flex' onSubmit={handleSubmit}>
                <div className='input-group'>
                    <input
                        ref={inputRef}
                        type='text'
                        className='form-control'
                        placeholder={placeholder}
                        value={searchKeyword}
                        onChange={handleInputChange}
                    />
                    {searchKeyword.trim() && (
                        <button
                            type='button'
                            className='btn btn-outline-secondary border-start-0'
                            onClick={() => {
                                onClearSearch();
                                setShowDropdown(false);
                                inputRef.current?.focus();
                            }}
                        >
                            <SvgIcon className='close' />
                        </button>
                    )}
                    <button type='submit' className='btn btn-outline-secondary'>
                        <SvgIcon className='search' />
                    </button>
                </div>
            </form>

            {/* 搜索结果下拉框 - 仅在用户搜索且有结果时显示 */}
            {showDropdown && (isSearchLoading || searchResults?.length > 0) && (
                <div className='position-absolute bg-white shadow-sm rounded-3 mt-1 w-100 search-results-dropdown z-1'>
                    <div className='p-2 overflow-auto' style={{ maxHeight: '350px', zIndex: '1050' }}>
                        {isSearchLoading ? (
                            <div className='text-center p-3'>
                                <div className='spinner-border spinner-border-sm text-secondary' role='status'>
                                    <span className='visually-hidden'>加载中...</span>
                                </div>
                                <span className='ms-2'>搜索中...</span>
                            </div>
                        ) : searchResults?.length > 0 ? (
                            <>
                                <div className='fw-bold text-secondary px-2 mb-2'>
                                    搜索结果 ({searchResults.length})
                                </div>
                                {searchResults.map((item) => (
                                    <div
                                        key={item.id}
                                        className='search-result-item p-2 rounded-2 mb-1 hover-bg-light'
                                        style={{
                                            cursor: item.permissions?.can_read ? 'pointer' : 'default',
                                        }}
                                    >
                                        <div className='d-flex justify-content-between align-items-center'>
                                            <div
                                                className='flex-grow-1'
                                                onClick={() => {
                                                    if (item.permissions?.can_read) {
                                                        onResultClick(item.id, item.permissions);
                                                        setShowDropdown(false);
                                                    }
                                                }}
                                            >
                                                <div className='d-flex align-items-center'>
                                                    <SvgIcon className='knowledge-base' />
                                                    <span className='ms-2 fw-medium'>
                                                        {item.highlighted_name ? (
                                                            <span
                                                                dangerouslySetInnerHTML={{
                                                                    __html: item.highlighted_name,
                                                                }}
                                                            />
                                                        ) : (
                                                            item.name
                                                        )}
                                                    </span>
                                                </div>
                                                <div className='small text-secondary d-flex align-items-center mt-1'>
                                                    <span
                                                        className='badge me-2'
                                                        style={{
                                                            backgroundColor:
                                                                item.type === 'private' ? '#e9ecef' : '#cff4fc',
                                                            color: item.type === 'private' ? '#495057' : '#055160',
                                                        }}
                                                    >
                                                        {item.type === 'private' ? '私有' : item.type}
                                                    </span>
                                                    {item.department && <span className='me-2'>{item.department}</span>}
                                                    {!item.permissions?.can_read && (
                                                        <span className='text-danger'>
                                                            <SvgIcon className='lock' />
                                                            <span className='ms-1'>无权限</span>
                                                        </span>
                                                    )}
                                                </div>
                                            </div>
                                            {!item.permissions?.can_read && (
                                                <button
                                                    className='btn btn-sm btn-outline-primary ms-2'
                                                    onClick={() => {
                                                        onRequestAccess(item.id, item.name);
                                                        setShowDropdown(false);
                                                    }}
                                                >
                                                    申请权限
                                                </button>
                                            )}
                                        </div>
                                    </div>
                                ))}
                            </>
                        ) : (
                            <div className='text-center text-secondary p-3'>未找到匹配的知识库</div>
                        )}
                    </div>
                </div>
            )}
        </div>
    );
};

export default SearchBar;
