import React, { useState, useEffect } from 'react';
import { useDispatch } from 'react-redux';
import { get } from '../../../../services/api';
import { showNotification } from '../../../../store/notification.slice';

/**
 * 文档预览模态框组件
 */
const DocumentPreviewModal = ({ show, documentId, knowledgeBaseId, onClose }) => {
    const dispatch = useDispatch();
    const [documentContent, setDocumentContent] = useState(null);
    const [loading, setLoading] = useState(false);

    useEffect(() => {
        if (show && documentId && knowledgeBaseId) {
            fetchDocumentContent();
        }
    }, [show, documentId, knowledgeBaseId]);

    const fetchDocumentContent = async () => {
        setLoading(true);
        try {
            const response = await get(`/knowledge-bases/${knowledgeBaseId}/document_content/`, {
                params: { document_id: documentId },
            });

            // 检查API响应格式，提取内容
            if (response.code === 200 && response.data) {
                setDocumentContent(response.data);
            } else if (response.data && response.data.code === 200) {
                // 如果数据包装在data属性中
                setDocumentContent(response.data.data);
            } else {
                // 兜底情况
                setDocumentContent(response);
            }
        } catch (error) {
            console.error('获取文档内容失败:', error);
            dispatch(
                showNotification({
                    type: 'danger',
                    message: '获取文档内容失败',
                })
            );
        } finally {
            setLoading(false);
        }
    };

    if (!show) return null;

    return (
        <div
            className='modal-backdrop'
            style={{
                position: 'fixed',
                top: 0,
                left: 0,
                right: 0,
                bottom: 0,
                backgroundColor: 'rgba(0, 0, 0, 0.5)',
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                zIndex: 1050,
            }}
        >
            <div
                className='modal-content bg-white rounded shadow'
                style={{
                    width: '800px',
                    maxWidth: '90%',
                    maxHeight: '80vh',
                    padding: '20px',
                    overflow: 'auto',
                }}
            >
                <div className='modal-header d-flex justify-content-between align-items-center mb-3'>
                    <h5 className='modal-title m-0'>{documentContent?.document_info?.name || '文档预览'}</h5>
                    <button type='button' className='btn-close' onClick={onClose} aria-label='Close'></button>
                </div>
                <div className='modal-body'>
                    {loading ? (
                        <div className='text-center py-4'>
                            <div className='spinner-border text-primary' role='status'>
                                <span className='visually-hidden'>加载中...</span>
                            </div>
                        </div>
                    ) : documentContent ? (
                        <div className='document-content'>
                            {documentContent.content &&
                                documentContent.content.map((section, index) => {
                                    let contentDisplay;
                                    try {
                                        // 尝试解析JSON内容
                                        const parsedContent = JSON.parse(section.content);
                                        contentDisplay = (
                                            <pre className='bg-light p-3 rounded'>
                                                {JSON.stringify(parsedContent, null, 2)}
                                            </pre>
                                        );
                                    } catch (e) {
                                        // 如果不是JSON，则直接显示文本内容
                                        contentDisplay = <p>{section.content}</p>;
                                    }

                                    return (
                                        <div key={index} className='mb-3 p-3 border rounded'>
                                            {contentDisplay}
                                        </div>
                                    );
                                })}
                        </div>
                    ) : (
                        <div className='text-center py-4 text-muted'>
                            <p>无法获取文档内容</p>
                        </div>
                    )}
                </div>
                <div className='modal-footer'>
                    <button type='button' className='btn btn-secondary' onClick={onClose}>
                        关闭
                    </button>
                </div>
            </div>
        </div>
    );
};

export default DocumentPreviewModal;
