import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post, put } from '../../services/api';
import { showNotification } from '../notification.slice';

// 获取权限申请列表
export const fetchPermissionsThunk = createAsyncThunk(
    'permissions/fetchPermissions',
    async (params = {}, { rejectWithValue }) => {
        try {
            const response = await get('/permissions/', { params });

            if (response && response.code === 200) {
                return {
                    results: response.data.results || [],
                    total: response.data.total || 0,
                    page: response.data.page || 1,
                    page_size: response.data.page_size || 10,
                };
            }
            return rejectWithValue('获取权限申请列表失败');
        } catch (error) {
            console.error('获取权限申请列表失败:', error);
            return rejectWithValue(error.response?.data?.message || '获取权限申请列表失败');
        }
    }
);

// 批准权限申请
export const approvePermissionThunk = createAsyncThunk(
    'permissions/approvePermission',
    async ({ id, responseMessage }, { rejectWithValue }) => {
        try {
            const response = await post(`/permissions/${id}/approve/`, {
                response_message: responseMessage || '已批准',
            });
            return response;
        } catch (error) {
            console.error('批准权限申请失败:', error);
            return rejectWithValue('批准权限申请失败');
        }
    }
);

// 拒绝权限申请
export const rejectPermissionThunk = createAsyncThunk(
    'permissions/rejectPermission',
    async ({ id, responseMessage }, { rejectWithValue }) => {
        try {
            const response = await post(`/permissions/${id}/reject/`, {
                response_message: responseMessage || '已拒绝',
            });
            return response;
        } catch (error) {
            console.error('拒绝权限申请失败:', error);
            return rejectWithValue('拒绝权限申请失败');
        }
    }
);

// 生成模拟数据
const generateMockUsers = () => {
    const users = [];
    const userNames = [
        { username: 'zhangsan', name: '张三', department: '达人组', position: '达人对接' },
        { username: 'lisi', name: '李四', department: '达人组', position: '达人对接' },
        { username: 'wangwu', name: '王五', department: '达人组', position: '达人对接' },
        { username: 'zhaoliu', name: '赵六', department: '达人组', position: '达人对接' },
        { username: 'qianqi', name: '钱七', department: '达人组', position: '达人对接' },
        { username: 'sunba', name: '孙八', department: '达人组', position: '达人对接' },
        { username: 'zhoujiu', name: '周九', department: '达人组', position: '达人对接' },
        { username: 'wushi', name: '吴十', department: '达人组', position: '达人对接' },
    ];

    for (let i = 1; i <= 20; i++) {
        const randomUser = userNames[Math.floor(Math.random() * userNames.length)];
        const hasAdminPermission = Math.random() > 0.8; // 20%的概率有管理员权限
        const hasEditPermission = Math.random() > 0.5; // 50%的概率有编辑权限
        const hasReadPermission = hasAdminPermission || hasEditPermission || Math.random() > 0.3; // 如果有管理员或编辑权限，一定有读取权限

        users.push({
            id: i.toString(),
            username: randomUser.username,
            name: randomUser.name,
            department: randomUser.department,
            position: randomUser.position,
            permissions_count: {
                read: hasReadPermission ? 1 : 0,
                edit: hasEditPermission ? 1 : 0,
                admin: hasAdminPermission ? 1 : 0,
            },
        });
    }

    return users;
};

// 获取用户权限列表
export const fetchUserPermissions = createAsyncThunk(
    'permissions/fetchUserPermissions',
    async (_, { rejectWithValue }) => {
        try {
            // 模拟API延迟
            await new Promise((resolve) => setTimeout(resolve, 1000));

            // 返回模拟数据
            return generateMockUsers();
        } catch (error) {
            return rejectWithValue(error.message);
        }
    }
);

// 更新用户权限
export const updateUserPermissions = createAsyncThunk(
    'permissions/updateUserPermissions',
    async ({ userId, permissions }, { dispatch, rejectWithValue }) => {
        try {
            const response = await put(`/users/${userId}/permissions/`, { permissions });

            if (response && response.code === 200) {
                dispatch(
                    showNotification({
                        message: '权限更新成功',
                        type: 'success',
                    })
                );
                return {
                    userId,
                    permissions: response.data.permissions,
                };
            }
            return rejectWithValue(response?.message || '更新权限失败');
        } catch (error) {
            dispatch(
                showNotification({
                    message: error.message || '更新权限失败',
                    type: 'danger',
                })
            );
            return rejectWithValue(error.message);
        }
    }
);

// 获取所有用户及其权限列表
export const fetchAllUserPermissions = createAsyncThunk(
    'permissions/fetchAllUserPermissions',
    async (params = {}, { rejectWithValue }) => {
        try {
            const response = await get('/permissions/all_permissions/', { params });

            if (response && response.code === 200) {
                return {
                    total: response.data.total,
                    page: response.data.page,
                    page_size: response.data.page_size,
                    results: response.data.results,
                };
            }

            return rejectWithValue('获取用户权限列表失败');
        } catch (error) {
            console.error('获取用户权限列表失败:', error);
            return rejectWithValue(error.response?.data?.message || '获取用户权限列表失败');
        }
    }
);
